
//末尾が //m の行は未検証の機械翻訳です

Ls.jpn = {
	"tt": "日本語",

	"cols": {
		"c": "アクションボタン",
		"dur": "間隔",
		"q": "品質 / ビットレート",
		"Ac": "オーディオコーデック",
		"Vc": "ビデオコーデック",
		"Fmt": "フォーマット / コンテナ",
		"Ahash": "オーディオチェックサム",
		"Vhash": "ビデオチェックサム",
		"Res": "解像度",
		"T": "ファイル形式",
		"aq": "オーディオ 品質 / ビットレート",
		"vq": "ビデオ 品質 / ビットレート",
		"pixfmt": "サブサンプリング / ピクセル構造",
		"resw": "水平解像度",
		"resh": "垂直解像度",
		"chs": "オーディオチャンネル",
		"hz": "サンプリングレート",
	},

	"hks": [
		[
			"misc",
			["ESC", "閉じる"],

			"file-manager",
			["G", "リスト / グリッド表示を切り替える"],
			["T", "サムネイル / アイコンを切り替える"],
			["⇧ A/D", "サムネイルサイズ"],
			["ctrl-K", "選択した項目を削除"],
			["ctrl-X", "選択範囲をクリップボードに切り取る"],
			["ctrl-C", "選択範囲をクリップボードにコピー"],
			["ctrl-V", "ここに貼り付け（移動/コピー）"],
			["Y", "選択した項目をダウンロード"],
			["F2", "選択した項目の名前を変更"],

			"file-list-sel",
			["space", "ファイル選択の切り替え"],
			["↑/↓", "選択カーソルを移動"],
			["ctrl ↑/↓", "カーソルとビューポートを移動"],
			["⇧ ↑/↓", "前/次のファイルを選択"],
			["ctrl-A", "すべてのファイル / フォルダを選択"],
		], [
			"navigation",
			["B", "パンくずリスト / ナビペインを切り替える"],
			["I/K", "前/次のフォルダ"],
			["M", "親フォルダ（または現在のフォルダを展開解除）"],
			["V", "ナビペインのフォルダ / テキストファイルを切り替える"],
			["A/D", "ナビペインサイズ"],
		], [
			"audio-player",
			["J/L", "前/次の曲"],
			["U/O", "10秒前/後スキップ"],
			["0..9", "0%～90%へジャンプ"],
			["P", "再生/一時停止（開始も）"],
			["S", "再生中の曲を選択"],
			["Y", "曲をダウンロード"],
		], [
			"image-viewer",
			["J/L, ←/→", "前/次の画像"],
			["Home/End", "最初/最後の画像"],
			["F", "フルスクリーン"],
			["R", "時計回りに回転"],
			["⇧ R", "反時計回りに回転"],
			["S", "画像を選択"],
			["Y", "画像をダウンロード"],
		], [
			"video-player",
			["U/O", "10秒前/後へスキップ"],
			["P/K/Space", "再生/一時停止"],
			["C", "自動再生"],
			["V", "ループ"],
			["M", "ミュート"],
			["[ and ]", "ループ間隔を設定"],
		], [
			"textfile-viewer",
			["I/K", "前/次のファイル"],
			["M", "テキストファイルを閉じる"],
			["E", "テキストファイルの編集"],
			["S", "ファイルを選択（切り取り/コピー/名前変更）"],
			["Y", "テキストファイルをダウンロード"],
			["⇧ J", "JSONを整形する"],
		]
	],

	"m_ok": "OK",
	"m_ng": "キャンセル",

	"enable": "有効",
	"danger": "危険",
	"clipped": "クリップボードにコピーされました",

	"ht_s1": "秒",
	"ht_s2": "秒",
	"ht_m1": "分",
	"ht_m2": "分",
	"ht_h1": "時間",
	"ht_h2": "時間",
	"ht_d1": "日",
	"ht_d2": "日",
	"ht_and": " と ",

	"goh": "コントロールパネル",
	"gop": '前のフォルダ">prev',
	"gou": '親フォルダ">up',
	"gon": '次のフォルダ">next',
	"logout": "ログアウト ",
	"login": "ログイン",
	"access": " アクセス",
	"ot_close": "サブメニューを閉じる",
	"ot_search": "`属性、パス/名前、音楽タグ、またはそれらの組み合わせでファイルを検索$N$N`foo bar` = «foo» と «bar» の両方を含める。$N`foo -bar` = «foo» を含み、«bar» を含まない必要があります。$N`^yana .opus$` = «yana» で始まり、«opus» ファイルである$N`&quot;try unite&quot;` = «try unite» だけを含む$N$N日付形式は iso-8601。たとえば、$N`2009-12-31` や `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: 最近アップロードした投稿を削除するか、未完成の投稿を中止",
	"ot_bup": "bup: 基本的なアップローダー。Netscape 4.0 もサポートしています。",
	"ot_mkdir": "mkdir: 新しいディレクトリを作成",
	"ot_md": "new-file: 新しいテキストファイルを作成",
	"ot_msg": "msg: サーバーログにメッセージを送信",
	"ot_mp": "メディアプレーヤー設定",
	"ot_cfg": "設定オプション",
	"ot_u2i": 'up2k: ファイルをアップロードする (書き込みアクセス権がある場合)、または検索モードに切り替えてファイルがサーバーのどこかに存在するかどうかを確認$N$Nアップロードは再開可能で、マルチスレッドであり、ファイルのタイムスタンプが保持されますが、[🎈] (基本的なアップローダー) よりも多くの CPU を使用します<br /><br />アップロード中、このアイコンは進行状況インジケーターになります。',
	"ot_u2w": 'up2k: 再開サポート付きのファイルのアップロード（ブラウザを閉じて、後で同じファイルをドロップします）$N$Nマルチスレッドで、ファイルのタイムスタンプが保持されますが、[🎈]（基本的なアップローダー）よりも多くの CPU を使用します。<br /><br />アップロード中は、このアイコンが進行状況インジケーターになります。',
	"ot_noie": 'Chrome / Firefox / Edgeを利用してください',

	"ab_mkdir": "ディレクトリを作成",
	"ab_mkdoc": "新しいテキストファイル",
	"ab_msg": "メッセージをサーバーログに送信",

	"ay_path": "フォルダへジャンプ",
	"ay_files": "ファイルへジャンプ",

	"wt_ren": "選択した項目の名前を変更する$Nホットキー: F2",
	"wt_del": "選択した項目を削除$Nホットキー: ctrl-K",
	"wt_cut": "選択した項目を切り取る &lt;small&gt;(その後別の場所に貼り付ける)&lt;/small&gt;$Nホットキー: ctrl-X",
	"wt_cpy": "選択した項目をクリップボード$Nにコピー（別の場所に貼り付ける）$Nホットキー: ctrl-C",
	"wt_pst": "以前に切り取った/コピーした選択範囲を貼り付ける$Nホットキー: ctrl-V",
	"wt_selall": "すべてのファイルを選択$Nホットキー: ctrl-A（ファイルにフォーカスがあるとき）",
	"wt_selinv": "選択を反転",
	"wt_zip1": "このフォルダを圧縮してダウンロード",
	"wt_selzip": "選択内容を圧縮してダウンロード",
	"wt_seldl": "選択した項目を個別のファイルとしてダウンロード$Nホットキー: Y",
	"wt_npirc": "IRC形式のトラック情報をコピーする",
	"wt_nptxt": "プレーンテキストのトラック情報をコピー",
	"wt_m3ua": "m3uプレイリストに追加 (後で <code>📻コピー</code> をクリック)",
	"wt_m3uc": "m3uプレイリストをクリップボードにコピー",
	"wt_grid": "グリッド / リスト表示を切り替える$Nホットキー: G",
	"wt_prev": "前のトラック$Nホットキー: J",
	"wt_play": "再生 / 一時停止$Nホットキー: P",
	"wt_next": "次のトラック$Nホットキー: L",

	"ul_par": "並列アップロード:",
	"ut_rand": "ファイル名をランダム化する",
	"ut_u2ts": "最終更新日時のタイムスタンプ$Nファイルシステムからサーバーへコピーする\">📅",
	"ut_ow": "サーバー上の既存のファイルを上書きする？$N🛡️: しない（代わりに新しいファイル名を生成する）$N🕒: サーバーのファイルが古い場合は上書きする$N♻️: ファイルが異なる場合は常に上書きする$N⏭️: 既存のファイルをすべて無条件にスキップする",
	"ut_mt": "アップロード中に他のファイルのハッシュを継続する$N$NCPUやHDDがボトルネックになっている場合は無効にしてください",
	"ut_ask": 'aアップロードを開始する前に確認を求める">💭',
	"ut_pot": "UIをシンプルにすることで$N低速デバイスでのアップロード速度を向上させる",
	"ut_srch": "実際にはアップロードせず、代わりにファイルが既にアップロードされているかどうかを確認 $N すでにサーバー上に存在（読み取り可能なすべてのフォルダをスキャン）",
	"ut_par": "0に設定するとアップロードを一時停止$N$N接続が遅い / 遅延が大きい場合は増やす$N$NLANやサーバーのHDDがボトルネックになっている場合は1にする",
	"ul_btn": "ファイル / フォルダを<br>ここにドロップしてください（またはクリックしてください）",
	"ul_btnu": "ア ッ プ ロ ー ド",
	"ul_btns": "検 索",

	"ul_hash": "ハッシュ",
	"ul_send": "送信",
	"ul_done": "完了",
	"ul_idle1": "キューにはまだアップロードは登録されていない",
	"ut_etah": "平均 &lt;em&gt;ハッシュ化&lt;/em&gt; 速度と完了予想時間",
	"ut_etau": "平均 &lt;em&gt;アップロード&lt;/em&gt; 速度と完了予想時間",
	"ut_etat": "平均 &lt;em&gt;合計&lt;/em&gt; 速度と完了予想時間",

	"uct_ok": "正常に完了",
	"uct_ng": "NG: 失敗 / 拒否 / 見つからない",
	"uct_done": "OKとNGの組み合わせ",
	"uct_bz": "ハッシュ化またはアップロード",
	"uct_q": "アイドル状態、保留中",

	"utl_name": "ファイル名",
	"utl_ulist": "リスト",
	"utl_ucopy": "コピー",
	"utl_links": "リンク",
	"utl_stat": "状態",
	"utl_prog": "進捗",

	// keep short:
	"utl_404": "404",
	"utl_err": "エラー",
	"utl_oserr": "OS-エラー",
	"utl_found": "発見",
	"utl_defer": "延期",
	"utl_yolo": "YOLO",
	"utl_done": "完了",

	"ul_flagblk": "ファイルがキューに追加されました</b><br>しかし、別のブラウザタブにはビジー状態のup2kがあり、<br>それが終わるまで待機します",
	"ul_btnlk": "サーバー構成によりこのスイッチはこの状態にロックされています",

	"udt_up": "アップロード",
	"udt_srch": "検索",
	"udt_drop": "ここにドロップ",

	"u_nav_m": '<h6>はい、何かもってますか？</h6><code>Enter</code> = ファイル（1つ以上）\n<code>ESC</code> = 1つのフォルダ（サブフォルダを含む）',
	"u_nav_b": '<a href="#" id="modal-ok">ファイル</a><a href="#" id="modal-ng">フォルダ</a>',

	"cl_opts": "スイッチ",
	"cl_hfsz": "ファイルサイズ",
	"cl_themes": "テーマ",
	"cl_langs": "言語",
	"cl_ziptype": "フォルダダウロード",
	"cl_uopts": "up2kスイッチ",
	"cl_favico": "ファビコン",
	"cl_bigdir": "ディレクトリの最大数",
	"cl_hsort": "#ソート",
	"cl_keytype": "キーの表記タイプ",
	"cl_hiddenc": "非表示の列",
	"cl_hidec": "非表示",
	"cl_reset": "リセット",
	"cl_hpick": "下の表で非表示にするには列ヘッダーをタップします",
	"cl_hcancel": "列の非表示を解除",
	"cl_rcm": "右クリックメニュー",
	"cl_gauto": "自動グリッド", //m

	"ct_grid": '田 グリッド',
	"ct_ttips": '◔ ◡ ◔">ℹ️ ツールチップ',
	"ct_thumb": 'グリッドビューではアイコンまたはサムネイルを切り替える$Nホットキー: T">🖼️ サムネイル',
	"ct_csel": 'グリッドビューでファイルを選択するにはCtrlとShiftを使用する。">選択',
	"ct_dsel": 'グリッドビューでドラッグ選択を使用する。">ドラッグ', //m
	"ct_dl": 'ファイルをクリックしたときに強制的にダウンロードする（インラインで表示しない）">dl',
	"ct_ihop": '画像ビューアを閉じたら最後に表示したファイルまでスクロールする。">g⮯',
	"ct_dots": '隠しファイルを表示する（サーバーが許可している場合）">隠しファイル',
	"ct_qdel": 'ファイルを削除するときは確認を一度だけ求める">qdel',
	"ct_dir1st": 'ファイルの前にフォルダを並べ替える">📁 優先',
	"ct_nsort": '自然ソート（先頭に数字があるファイル名の場合）">nsort',
	"ct_utc": 'すべての日時をUTCで表示">UTC',
	"ct_readme": 'フォルダ一覧にREADME.mdを表示">📜 readme',
	"ct_idxh": 'フォルダ一覧の代わりにindex.htmlを表示">htm',
	"ct_sbars": 'スクロールバーを表示">⟊',

	"cut_umod": "サーバー上にファイルが既に存在する場合はサーバーの最終更新タイムスタンプをローカルファイルと一致するように更新します（書き込み+削除権限が必要です）\">re📅",

	"cut_turbo": "yoloボタンを使用する場合できればこれを有効にしないでください:$N$N大量のファイルをアップロードしていて何らかの理由で再起動する必要があり、できるだけ早くアップロードを続行したい場合にこれを使用します。$N$Nこれはハッシュチェックを単純な<em>&quot;これはサーバー上で同じファイルサイズですか？&quot;</em>に置き換えます。そのため、ファイルの内容が異なる場合はアップロードされません。$N$Nアップロードが完了したらこれをオフにし、同じファイルを再度 &quot;アップロード&quot; してクライアントに検証させる必要があります。\">turbo",

	"cut_datechk": "turboボタンが有効になっていなければ効果はありません$N$Nyolo要素をわずかに減らしサーバー上のファイルのタイムスタンプが一致するかどうかを確認します。$N$N<em>理論的</em>にはほとんどの未完了 / 破損したアップロードを把握できるはずですが、その後ターボを無効にして検証パスを実行する代わりにはなりません。\">date-chk",

	"cut_u2sz": "各アップロードチャンクのサイズ（MiB）; 大西洋を横断する場合は大きな値の方が飛行効率が良いです。接続の信頼性が低い場合は、小さな値を試してください。",

	"cut_flag": "一度にアップロードするタブは1つだけにしてください $N -- 他のタブでもこれを有効にする必要があります $N -- 同じドメインのタブにのみ影響します",

	"cut_az": "ファイルの最小サイズ順ではなくアルファベット順にファイルをアップロードします。$N$アルファベット順にするとサーバー上で何か問題が発生した場合に簡単に確認できるようになりますが、光ファイバー / LANでのアップロードが若干遅くなります。",

	"cut_nag": "アップロード完了時のOS通知$N（ブラウザまたはタブがアクティブでない場合のみ）",
	"cut_sfx": "アップロードが完了すると音声アラートが鳴ります$N（ブラウザまたはタブがアクティブでない場合のみ）",

	"cut_mt": "マルチスレッドを使用してファイルハッシュを高速化する$N$NこれはWebワーカーを使用し$N追加のRAM（最大512 MiB）が必要$N$Nこれによりhttpsは30%高速化、httpは4.5倍高速化r\">mt",

	"cut_wasm": "ブラウザの組込みのハッシュ関数の代わりにwasmを使用します。Chromeベースのブラウザでは速度が向上しますがCPU負荷が増加します。また、Chromeの古いバージョンの多くにはこれを有効にするとブラウザがすべてのRAMを消費してクラッシュするというバグがあります。\">wasm",

	"cft_text": "ファビコンテキスト（無効にするには空白にして更新してください）",
	"cft_fg": "テキストカラー",
	"cft_bg": "背景色",

	"cdt_lim": "フォルダに表示するファイルの最大数",
	"cdt_ask": "一番下までスクロールしたときに$N更にファイルを読み込む代わりに$N何をするか尋ねる",
	"cdt_hsort": "`メディアURLに含めるソートルール (`,sorthref`) の数。0に設定するとメディアリンクをクリックした際にそのリンクに含まれるソートルールも無視されます。",
	"cdt_ren": "カスタム右クリックメニューを有効にしてもShiftキーを押しながら右クリックすることで通常のメニューにアクセスできます。\">有効",
	"cdt_rdb": "カスタム右クリックメニューが開いている状態で再度右クリックしたときに通常のメニューを表示する\">x2", //m

	"tt_entree": "ナビペインを表示（ディレクトリツリーサイドバー）$Nホットキー: B",
	"tt_detree": "パンくずリストを表示$Nホットキー: B",
	"tt_visdir": "選択したフォルダまでスクロール",
	"tt_ftree": "フォルダツリー / テキストファイルの切り替え$Nホットキー: V",
	"tt_pdock": "上部のドッキングされたペインに親フォルダを表示",
	"tt_dynt": "ツリーが拡大するにつれて自動的に増加",
	"tt_wrap": "単語の折り返し",
	"tt_hover": "ホバーすると溢れた線を表示する$N( マウスを押さない限りスクロールが中断されます $N&nbsp; カーソルは左余白です )",
	"tt_gauto": "フォルダー内容に応じてグリッドまたはリスト表示", //m
	"tt_gathr": "この割合のファイルが画像/動画ならグリッドを使用", //m

	"ml_pmode": "フォルダの末尾...",
	"ml_btns": "コマンド",
	"ml_tcode": "変換",
	"ml_tcode2": "この形式に変換",
	"ml_tint": "色合い",
	"ml_eq": "オーディオイコライザー",
	"ml_drc": "ダイナミックレンジコンプレッサー",
	"ml_ss": "無音をスキップ", //m

	"mt_loop": "1曲をループ/リピート再生\">🔁",
	"mt_one": "1曲で止める\">1️⃣",
	"mt_shuf": "各フォルダ内の曲をシャッフルする\">🔀",
	"mt_aplay": "サーバーにアクセスするためにクリックしたリンクに曲IDがある場合は自動再生されます$N$Nこれを無効にすると、音楽を再生するときにページのURLが曲IDで更新されなくなります。これにより設定が失われてもURLが残っている場合の自動再生が防止されます。\">a▶",
	"mt_preload": "ギャップレス再生のために曲の終わり近くに次の曲の読み込みを開始する\">preload",
	"mt_prescan": "最後の曲が終了する前に次のフォルダへ移動し$Nウェブブラウザが$N再生を停止しないようにする\">nav",
	"mt_fullpre": "曲全体を事前ロードしてみる;$N✅ <b>信頼できない</b>接続で有効にする、$N❌ 低速接続では<b>無効</b>にする\">full",
	"mt_fau": "携帯電話では、次の曲が十分に早く読み込まれない場合に音楽が停止しないようにする（タグの表示が不安定になる可能性があります）\">☕️",
	"mt_waves": "波形シークバー:$Nスクラバーにオーディオ振幅を表示する\">~s",
	"mt_npclip": "現在再生中の曲をクリップボードに保存するためのボタンを表示する\">/np",
	"mt_m3u_c": "選択した曲をm3u8プレイリストエントリとして$Nクリップボードに保存するためのボタンを表示する\">📻",
	"mt_octl": "OS統合（メディアホットキー / OSD）\">os-ctl",
	"mt_oseek": "OS統合によるシークを許可する$N$N注: 一部のデバイス（iPhone）では$N次の曲ボタンの代わりになります\">シーク",
	"mt_oscv": "OSDでアルバムカバーを表示する\">art",
	"mt_follow": "再生中の曲をスクロールして表示したままにする\">🎯",
	"mt_compact": "コントローラーを小さく\">⟎",
	"mt_uncache": "キャッシュクリア &nbsp;（ブラウザが破損した曲のコピーをキャッシュしているために$N再生できない場合はこれを試してください）\">uncache",
	"mt_mloop": "開いているフォルダをループ\">🔁 ループ",
	"mt_mnext": "次のフォルダを読み込んで続行\">📂 次",
	"mt_mstop": "再生を停止\">⏸ 停止",
	"mt_cflac": "flac / wavを{0}に変換\">flac",
	"mt_caac": "aac / m4aを{0}に変換\">aac",
	"mt_coth": "その他すべて（mp3以外）を{0}に変換\">その他",
	"mt_c2opus": "デスクトップ、ノート、Androidに最適\">opus",
	"mt_c2owa": "opus-weba（iOS 17.5以降）\">owa",
	"mt_c2caf": "opus-caf（iOS 11から17まで）\">caf",
	"mt_c2mp3": "非常に古いデバイスでこれを使用\">mp3",
	"mt_c2flac": "最高の音質、ダウンロードサイズが大きい\">flac",
	"mt_c2wav": "非圧縮再生（さらに大きい）\">wav",
	"mt_c2ok": "素晴らしい、良い選択です",
	"mt_c2nd": "これは現在のデバイスに推奨される出力形式ではありませんが、問題ありません",
	"mt_c2ng": "現在のデバイスはこの出力形式をサポートしていないようですが、とにかく試してみましょう",
	"mt_xowa": "iOSにはこのフォーマットを使用したバックグラウンド再生を妨げるバグがあります; 代わりにcafまたはmp3を使用してください",
	"mt_tint": "シークバーの背景レベル（0～100）を調整し$Nバッファリングの邪魔にならにようにする",
	"mt_eq": "`イコライザーとゲイン制御を有効にします;$N$Nブースト `0` = 標準音量100%（変更なし）$N$N幅 `1 &nbsp;` = 標準ステレオ（変更なし）$N幅 `0.5` = 左右のクロスフィード50%$N幅 `0 &nbsp;` = モノラル$N$Nブースト `-0.8` &amp; 幅 `10` = ボーカル除去 :^)$N$Nイコライザーを有効にするとギャップレスアルバムは完全にギャップレスになります。そのため、それを気に場合すべての値をゼロ（幅 = 1を除く）にしてイコライザーをオンにしたままにしてください。",
	"mt_drc": "ダイナミックレンジコンプレッサー（ボリュームフラットナー / ブリックウォーラー）を有効にします; EQでスパゲッティのバランスをとることもできます。そのため、EQのフィールドを「幅」以外すべて0に設定してください。$N$Nしきい値を超えるオーディオの音量を下げる; しきい値を超えるRATIO dBごとに1dBの出力されますしきい値-24と比率12のデフォルト値は、-22dBを超えることはなく、イコライザーのブーストを0.8に、またはATK 0とRLS 90などの非常に大きな値にした場合1.8まで安全に上げられます (Firefoxでのみ機能し、他のブラウザーではRLSは最大 1 です)。$N$N（Wikipedia を参照してください。もっとわかりやすく説明されています）",
	"mt_ss": "`無音スキップを有効化；音量が `音` 未満で、再生位置が最初の `始`% または最後の `終`% にある場合、開始/終了付近で再生速度を `速` 倍します", //m
	"mt_ssvt": "音量しきい値 (0-255)\">音", //m
	"mt_ssts": "有効しきい値 (トラック%, 開始)\">始", //m
	"mt_sste": "有効しきい値 (トラック%, 終了)\">終", //m
	"mt_sssm": "再生速度倍率\">速", //m

	"mb_play": "再生",
	"mm_hashplay": "このオーディオファイルを再生しますか？",
	"mm_m3u": "再生するには<code>Enter/OK</code>を押します\n編集するには<code>ESC/キャンセル</code>を押してください",
	"mp_breq": "Firefox 82以降、Chrome 73以降、またはiOS 15以降が必要です",
	"mm_bload": "読み込み中...",
	"mm_bconv": "{0}に変換中。お待​​ちください。...",
	"mm_opusen": "現在のブラウザはaac / m4aファイルを再生できません;\nOpusへのトランスコードが有効になりました",
	"mm_playerr": "再生に失敗: ",
	"mm_eabrt": "再生の試行はキャンセルされました",
	"mm_enet": "インターネット接続が不安定です",
	"mm_edec": "このファイルは破損している？？",
	"mm_esupp": "現在のブラウザはこのオーディオ形式に対応していません",
	"mm_eunk": "不明なエラー",
	"mm_e404": "オーディオを再生できませんでした。エラー404: ファイルが見つかりません。",
	"mm_e403": "オーディオを再生できませんでした。エラー403: アクセス拒否。\n\nF5キーを押してリロードしてみてください。ログアウトしている可能性があります。",
	"mm_e415": "オーディオを再生できませんでした。エラー415: ファイルの変換に失敗しました。サーバーログを確認してください。", //m
	"mm_e500": "オーディオを再生できませんでした。エラー500: サーバーログを確認してください。",
	"mm_e5xx": "オーディオを再生できませんでした。サーバーエラー ",
	"mm_nof": "近くにオーディオファイルが見つかりません",
	"mm_prescan": "次に再生する曲を探しています...",
	"mm_scank": "次の曲を見つけました:",
	"mm_uncache": "キャッシュがクリアされました; 次回の再生時にすべての曲が再ダウンロードされます",
	"mm_hnf": "その曲はもう存在しません",

	"im_hnf": "その画像はもう存在しません",

	"f_empty": 'このフォルダは空です',
	"f_chide": 'これにより列 «{0}» が非表示になります\n\n設定タブで列の非表示を解除できます',
	"f_bigtxt": "このファイルは {0} MiB の大きさです -- 本当にテキストとして表示しますか？",
	"f_bigtxt2": "代わりにファイルの末尾だけを表示しませんか？これにより追跡も有効になり、新しく追加されたテキスト行がリアルタイムで表示されます。",
	"fbd_more": '<div id="blazy">表示中 <code>{0}</code> / <code>{1}</code> ファイル; <a href="#" id="bd_more">{2}件を表示</a> または <a href="#" id="bd_all">すべて表示</a></div>',
	"fbd_all": '<div id="blazy">表示中 <code>{0}</code> / <code>{1}</code> ファイル; <a href="#" id="bd_all">すべて表示</a></div>',
	"f_anota": "{1}件のアイテムのうち {0}件が選択されました;\nフォルダ全体を選択するには、まず一番下までスクロールします",

	"f_dls": '現在のフォルダ内のファイルリンクは\nダウンロードリンクに変更されました',
	"f_dl_nd": 'フォルダーをスキップしています（代わりに zip/tar ダウンロードを使用してください）：\n', //m

	"f_partial": "現在アップロード中のファイルを安全にダウンロードするには、同じファイル名で<code>.PARTIAL</code>拡張子がないファイルをクリックしてください。これを行うにはキャンセルまたはEscキーを押してください。\n\nOK / Enter を押すとこの警告は無視され、代わりに<code>.PARTIAL</code>スクラッチファイルのダウンロードが続行されますが、ほとんどの場合データが破損することになります。",

	"ft_paste": "{0}件のアイテムを貼り付け$Nホットキー: ctrl-V",
	"fr_eperm": '名前を変更できません:\nこのフォルダではの"移動"の権限がありません',
	"fd_eperm": '削除できません:\nこのフォルダではの"削除"の権限がありません',
	"fc_eperm": '切り取りできません:\nこのフォルダではの"移動"の権限がありません',
	"fp_eperm": '貼付けできません:\nこのフォルダではの"書込"の権限がありません',
	"fr_emore": "名前を変更する項目を1つ以上選択してください",
	"fd_emore": "削除する項目を1つ以上選択してください",
	"fc_emore": "切り取る項目を1つ以上選択してください",
	"fcp_emore": "クリップボードにコピーする項目を1つ以上選択してください",

	"fs_sc": "現在表示中のフォルダを共有する",
	"fs_ss": "選択したファイルを共有する",
	"fs_just1d": "複数のフォルダを選択することはできません\nまた、1回の選択でファイルとフォルダを混在させることはできません。",
	"fs_abrt": "❌ 中止",
	"fs_rand": "🎲 ランダム名",
	"fs_go": "✅ 共有を作成",
	"fs_name": "名前",
	"fs_src": "ソース",
	"fs_pwd": "パスワード",
	"fs_exp": "有効期限",
	"fs_tmin": "分",
	"fs_thrs": "時間",
	"fs_tdays": "日",
	"fs_never": "無期限",
	"fs_pname": "任意のリンク名; 空白の場合はランダムになります",
	"fs_tsrc": "共有するファイルまたはフォルダ",
	"fs_ppwd": "任意のパスワード",
	"fs_w8": "共有の作成...",
	"fs_ok": "<code>Enter/OK</code>を押してクリップボードに保存します\n<code>ESC/キャンセル</code>を押して閉じます",

	"frt_dec": "壊れたファイル名を修正するかもしれません\">url-decode",
	"frt_rst": "変更したファイル名を元の名前に戻す\">↺ リセット",
	"frt_abrt": "中止してこのウィンドウを閉じる\">❌ キャンセル",
	"frb_apply": "名前の変更を適用",
	"fr_adv": "バッチ / メタデータ / パターン名変更\">詳細設定",
	"fr_case": "大文字と小文字を区別する正規表現\">case",
	"fr_win": "Windowsで安全な名前; <code>&lt;&gt;:&quot;\\|?*</code>を日本語の全角文字に置き換える\">win",
	"fr_slash": "<code>/</code>を新しいフォルダが作成されない文字に置き換える\">no /",
	"fr_re": "`元のファイル名に適用する正規表現検索パターン; キャプチャグループは、`(1)` や `(2)` のように、以下のフォーマットフィールドで参照することができるので、",
	"fr_fmt": "`foob​​ar2000 を参考にしています:$N`(title)` は曲名に置き換えられます。$N`[(artist) - ](title)` はアーティストが空白の場合は[この]部分をスキップします。$N`$lpad((tn),2,0)` はトラック番号を2桁にパディングします。",
	"fr_pdel": "削除",
	"fr_pnew": "名前をつけて保存",
	"fr_pname": "新しいプリセットの名前を入力します",
	"fr_aborted": "中止されました",
	"fr_lold": "古い名前",
	"fr_lnew": "新しい名前",
	"fr_tags": "選択したファイルのタグ（読み取り専用、参照のみ）:",
	"fr_busy": "{0}件のアイテムの名前を変更...\n\n{1}",
	"fr_efail": "名前の変更に失敗:\n",
	"fr_nchg": "新しい名前のうち {0}件は、<code>win</code> および/または <code>no /</code> により変更されました。\n\nこれらを変更後の新しい名前で続行しますか？",

	"fd_ok": "削除成功",
	"fd_err": "削除失敗:\n",
	"fd_none": "何も削除されませんでした; サーバー構成 (xbd) によってブロックされた可能性があります。",
	"fd_busy": "{0}件のアイテムを削除中...\n\n{1}",
	"fd_warn1": "これら {0}件のアイテムを削除しますか？",
	"fd_warn2": "<b>最後の警告！</b> 取り消し不可。削除しますか？",

	"fc_ok": "{0}件のアイテムを切り取り",
	"fc_warn": '{0}件のアイテムを切り取りました\n\nしかし: <b>この</b>ブラウザタブでのみ貼り付けることができます\n（選択範囲が非常に大きいため）',

	"fcc_ok": "{0}件のアイテムをクリップボードにコピー",
	"fcc_warn": '{0}件のアイテムをクリップボードにコピーしました\n\nしかし: <b>この</b>ブラウザタブでのみ貼り付けることができます\n（選択範囲が非常に大きいため）',

	"fp_apply": "これらの名前を使用する",
	"fp_skip": "競合をスキップ",  // トピックノート: "既存の名前をスキップ" （対象フォルダ内のファイル名）
	"fp_ecut": "最初にファイル / フォルダを切り取りまたはコピーし、貼り付け / 移動します\n\n注: 異なるブラウザタブ間で切り取り / 貼り付けが可能です",
	"fp_ename": "名前がすでに使用されているため、{0}件のアイテムはここに移動することはできません。続行するには、以下に新しい名前を入力するか名前を空白（\"競合をスキップ\"）にしてスキップしてください:",
	"fcp_ename": "名前がすでに使用されているため、{0}件のアイテムはここにコピーすることはできません。続行するには、以下に新しい名前を入力するか名前を空白（\"競合をスキップ\"）にしてスキップしてください:",
	"fp_emore": "まだ修正すべきファイル名の競合がいくつか残っています",
	"fp_ok": "移動完了",
	"fcp_ok": "コピー完了",
	"fp_busy": "{0}件のアイテムを移動中...\n\n{1}",
	"fcp_busy": "{0}件のアイテムをコピー中...\n\n{1}",
	"fp_abrt": "中止しています...",
	"fp_err": "移動に失敗:\n",
	"fcp_err": "コピーに失敗:\n",
	"fp_confirm": "これらの{0}件のアイテムをここに移動しますか？",
	"fcp_confirm": "これらの{0}件のアイテムをここにコピーしますか？",
	"fp_etab": '他のブラウザタブからクリップボードを読み取ることができませんでした',
	"fp_name": "デバイスからファイルをアップロードします。ファイル名を入力してください:",
	"fp_both_m": '<h6>貼り付けるものを選択</h6><code>Enter</code> = «{1}»から{0}件のファイルを移動\n<code>ESC</code> = デバイスから{2}件のファイルをアップロード',
	"fcp_both_m": '<h6>貼り付けるものを選択</h6><code>Enter</code> = «{1}»から{0}件のファイルをコピー\n<code>ESC</code> = デバイスから{2}件のファイルをアップロード',
	"fp_both_b": '<a href="#" id="modal-ok">移動</a><a href="#" id="modal-ng">アップロード</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">コピー</a><a href="#" id="modal-ng">アップロード</a>',

	"mk_noname": "それをする前に左側のテキストフィールドに名前を入力してください :p",
	"nmd_i1": "必要なファイル拡張子も追加します。例: <code>.md</code>",
	"nmd_i2": "削除権限がないため、<code>.{0}</code> ファイルのみを作成できます",

	"tv_load": "テキストドキュメントの読み込み中:\n\n{0}\n\n{1}%（{2} / {3} MiB ロード済み）",
	"tv_xe1": "テキストファイルを読み込めませんでした:\n\nエラー ",
	"tv_xe2": "404、ファイルが見つかりません",
	"tv_lst": "テキストファイルの一覧",
	"tvt_close": "フォルダビューに戻る$Nホットキー: M（または Esc）\">❌ 閉じる",
	"tvt_dl": "このファイルをダウンロード$Nホットキー: Y\">💾 ダウンロード",
	"tvt_prev": "前のドキュメントを表示$Nホットキー: i\">⬆ 前へ",
	"tvt_next": "次のドキュメントを表示$Nホットキー: K\">⬇ 次へ",
	"tvt_sel": "ファイルの選択 &nbsp;（切り取り/コピー/削除/...）$Nホットキー: S\">選択",
	"tvt_j": "jsonの整形$Nホットキー: shift-J\">j",
	"tvt_edit": "テキストエディタでファイルを開く$Nホットキー: E\">✏️ 編集",
	"tvt_tail": "ファイルの変更を監視する; 新しい行をリアルタイムで表示する\">📡 監視",
	"tvt_wrap": "ワードラップ\">↵",
	"tvt_atail": "ページ最下部までスクロールをロック\">⚓",
	"tvt_ctail": "端末カラーをデコード（ANSIエスケープコード）\">🌈",
	"tvt_ntail": "スクロールバック制限（読み込むテキストの最大バイト数）",

	"m3u_add1": "曲がm3uプレイリストに追加されました",
	"m3u_addn": "{0}曲をm3uプレイリストに追加しました",
	"m3u_clip": "m3uプレイリストがクリップボードにコピーされました\n\nsomething.m3uという新しいテキストファイルを作成し、そのドキュメントにプレイリストを貼り付けます; これで再生可能になります",

	"gt_vau": "動画は表示せず音声のみを再生する\">🎧",
	"gt_msel": "ファイル選択を有効にする; ファイルをCtrlキーを押しながらクリックすると上書き保存します$N$N&lt;em&gt;有効時: ファイル / フォルダをダブルクリックすると開きます&lt;/em&gt;$N$Nホットキー: S\">複数選択",
	"gt_crop": "中央切り抜きのサムネイル\">切抜き",
	"gt_3x": "高解像度サムネイル\">3x",
	"gt_zoom": "拡大",
	"gt_chop": "切断",
	"gt_sort": "並べ替え",
	"gt_name": "名前",
	"gt_sz": "サイズ",
	"gt_ts": "日付",
	"gt_ext": "種類",
	"gt_c1": "ファイル名をさらに短縮する（表示を減らす）",
	"gt_c2": "ファイル名を短縮する（詳細を表示）",

	"sm_w8": "検索中...",
	"sm_prev": "以下の検索結果は以前のクエリからのものです:\n  ",
	"sl_close": "検索結果を閉じる",
	"sl_hits": "{0}件の結果を表示中",
	"sl_moar": "さらに読み込む",

	"s_sz": "サイズ",
	"s_dt": "日付",
	"s_rd": "パス",
	"s_fn": "名前",
	"s_ta": "タグ",
	"s_ua": "Up@",
	"s_ad": "詳細.",
	"s_s1": "最小 MiB",
	"s_s2": "最大 MiB",
	"s_d1": "古い. iso8601",
	"s_d2": "新しい. iso8601",
	"s_u1": "アップロード後",
	"s_u2": "および/または前",
	"s_r1": "パスに含まれる &nbsp;（スペース区切り）",
	"s_f1": "名前に含まれる &nbsp;（-nopeで否定）",
	"s_t1": "タグに含まれる &nbsp;（^=開始、終了=$）",
	"s_a1": "特定のメタデータプロパティ",

	"md_eshow": "レンダリングできません ",
	"md_off": "[📜<em>readme</em>] 無効 [⚙️] -- ドキュメントを非表示",

	"badreply": "サーバーからの応答を解析できませんでした",

	"xhr403": "403: アクセスが拒否されました\n\nF5キーを押してみてください。ログアウトしている可能性があります",
	"xhr0": "不明（サーバーへの接続が失われたか、サーバーがオフラインになっている可能性があります）",
	"cf_ok": "申し訳ありません -- DD" + wah + "oS 保護が作動し\n\n約30秒で再開されます\n\n何も起こらない場合はF5キーを押してページを再読み込みしてください",
	"tl_xe1": "サブフォルダを一覧表示できませんでした:\n\nエラー ",
	"tl_xe2": "404: フォルダーが見つかりません",
	"fl_xe1": "フォルダ内のファイルを一覧表示できませんでした:\n\nエラー ",
	"fl_xe2": "404: フォルダーが見つかりません",
	"fd_xe1": "サブフォルダを作成できませんでした:\n\nエラー ",
	"fd_xe2": "404: 親フォルダが見つかりません",
	"fsm_xe1": "メッセージを送信できませんでした:\n\nエラー ",
	"fsm_xe2": "404: 親フォルダが見つかりません",
	"fu_xe1": "サーバーから投稿取り消しリストを読み込めませんでした:\n\nエラー ",
	"fu_xe2": "404: ファイルが見つかりません？？",

	"fz_tar": "非圧縮gnu-tarファイル（Linux / Mac）",
	"fz_pax": "非圧縮pax形式のtar（遅い）",
	"fz_targz": "gzip圧縮レベル3のgnu-tar$N$Nこれは通常非常に遅いので$N代わりに非圧縮tarを使用してください。",
	"fz_tarxz": "xz圧縮レベル1のgnu-tar$N$Nこれは通常非常に遅いので$N代わりに非圧縮のtarを使用してください。",
	"fz_zip8": "UTF8ファイル名のzip形式（Windows7以前では動作が不安定になる可能性があります）",
	"fz_zipd": "非常に古いソフトウェア用の従来のcp437ファイル名のzip",
	"fz_zipc": "cp437はcrc32を早期に計算します$NMS-DOS PKZIP v2.04g用（1993年10月）$N（ダウンロードを開始するまでの処理に時間がかかります）",

	"un_m1": "最近アップロードした動画を削除したり未完成の動画を中止したりできます。",
	"un_upd": "更新",
	"un_m4": "または以下のファイルを共有する:",
	"un_ulist": "表示",
	"un_ucopy": "コピー",
	"un_flt": "任意のフィルター:&nbsp; URLには以下を含める必要があります",
	"un_fclr": "フィルターをクリア",
	"un_derr": '未投稿の削除に失敗しました:\n',
	"un_f5": '何かが壊れています。リロードするかF5キーを押してみてください。',
	"un_uf5": "申し訳ありませんが、このアップロードを中止するにはページを更新する必要があります（例:F5キーまたはCtrl+Rキーを押す）",
	"un_nou": '<b>警告:</b> サーバーが混雑しているため未完了のアップロードを表示できません; しばらくしてから「更新」リンクをクリックしてください',
	"un_noc": '<b>警告:</b> 完全にアップロードされたファイルの未投稿化はサーバー設定で有効化 / 許可されていません',
	"un_max": "最初の2000件のファイルを表示中 (フィルターを使用)",
	"un_avail": "{0}件の最近のアップロードを削除できます<br />未完了のものは{1}件中止できます",
	"un_m2": "アップロード日時順に並べ替え; 新しい順:",
	"un_no1": "冗談だよ！アップロードされたものはどれも最新じゃない",
	"un_no2": "冗談だよ！そのフィルターに一致するアップロードに最新のものはありません",
	"un_next": "次の{0}件のファイルを削除します",
	"un_abrt": "中止",
	"un_del": "削除",
	"un_m3": "最近のアップロードを読み込み中...",
	"un_busy": "{0}件のファイルを削除中...",
	"un_clip": "{0}件のリンクをクリップボードにコピーしました",

	"u_https1": "あなたはするべき",
	"u_https2": "httpsに切り替える",
	"u_https3": "パフォーマンス向上のため",
	"u_ancient": '現在のブラウザは驚くほど古いです -- <a href="#" onclick="goto(\'bup\')">代わりにbup</a>を使った方がいいかもしれません',
	"u_nowork": "Firefox 53以降、Chrome 57以降、またはiOS 11以降が必要です",
	"tail_2old": "Firefox 105以降、Chrome 71以降、またはiOS 14.5以降が必要です",
	"u_nodrop": '現在のブラウザは古すぎてドラッグ＆ドロップによるアップロードに対応していません',
	"u_notdir": "それはフォルダではありません！\n\nブラウザが古すぎです、\n代わりにドラッグドロップを試してください",
	"u_uri": "他のブラウザウィンドウから画像をドラッグアンドドロップするには、\n大きなアップロードボタンにドロップしてください",
	"u_enpot": '<a href="#">potato UI</a>に切り替える （アップロード速度が向上する可能性があります）',
	"u_depot": '<a href="#">fancy UI</a>に切り替える（アップロード速度が低下する可能性があります）',
	"u_gotpot": 'アップロード速度を向上させるためにポテトUIに切り替えました。\n\n同意しない場合は遠慮なく元に戻してください！',
	"u_pott": "<p>ファイル: &nbsp; <b>{0}</b> 完了済み, &nbsp; <b>{1}</b> 失敗, &nbsp; <b>{2}</b> ビジー, &nbsp; <b>{3}</b> キュー内</p>",
	"u_ever": "これは基本的なアップローダーです; up2kは少なくとも以下が必要です<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'これは基本的なアップローダーです; <a href="#" id="u2yea">up2k</a>の方が優れています',
	"u_uput": '速度を最適化（チェックサムをスキップ）',
	"u_ewrite": 'このフォルダへの書き込み権限がありません',
	"u_eread": 'このフォルダーへの読み取りアクセス権がありません',
	"u_enoi": 'サーバー設定でファイル検索が有効になっていません',
	"u_enoow": "ここでは上書きは機能しません; 削除権限が必要です",
	"u_badf": 'これらの {0}件のファイル（合計 {1}件中）はファイルシステムの権限が原因でスキップされた可能性があります:\n\n',
	"u_blankf": 'これらの {0}件のファイル（合計 {1}件中）は空白です; それでもアップロードしますか？\n\n',
	"u_applef": 'これらの {0}件のファイル（合計 {1}件中）はおそらく不要です;\n次のファイルをスキップするには<code>OK/Enter</code>を押してください、\n除外しない場合は<code>キャンセル/ESC</code>を押してそれらもアップロードしてください:\n\n',
	"u_just1": '\nファイルを1つだけ選択した方がうまくいくかもしれません',
	"u_ff_many": "<b>Linux / MacOS / Android,</b>を使用している場合この量のファイルにより<a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\">Firefoxがクラッシュする<em>可能性</em></a>があります\nその場合はもう一度お試しください（または Chrome を使用してください）。",
	"u_up_life": "このアップロードは {0}後に\nサーバーから削除されます。",
	"u_asku": 'これらの{0}件のファイルを<code>{1}</code>にアップロードします',
	"u_unpt": "左上のボタン🧯を使ってこのアップロードを取り消し / 削除できます",
	"u_bigtab": '{0}件のファイルを表示しようとしています\n\nブラウザがクラッシュする可能性がありますが、よろしいですか？',
	"u_scan": 'ファイルをスキャン中...',
	"u_dirstuck": 'ディレクトリ走査が次の {0}件のアイテムへのアクセス中に停止しました; スキップします:',
	"u_etadone": '完了 ({0}, {1}件のファイル)',
	"u_etaprep": '（アップロード準備中）',
	"u_hashdone": 'ハッシュ化完了',
	"u_hashing": 'ハッシュ',
	"u_hs": 'ハンドシェイク中...',
	"u_started": "ファイルをアップロード中です; 参照 [🚀]",
	"u_dupdefer": "複製; 他のすべてのファイルの処理完了後に処理されます",
	"u_actx": "他のウィンドウ/タブに切り替えるときに<br />パフォーマンスの低下を防ぐにはこのテキストをクリックしてください",
	"u_fixed": "OK!&nbsp; 修正しました 👍",
	"u_cuerr": "{0} / {1} のチャンクのアップロードに失敗しました;\nおそらく無害、継続中\n\nファイル: {2}",
	"u_cuerr2": "サーバーがアップロードを拒否しました（{0} / {1}のチャンク）;\n後で再試行します\n\nファイル: {2}\n\nエラー ",
	"u_ehstmp": "再試行します; 右下を参照",
	"u_ehsfin": "サーバーがアップロードの完了リクエストを拒否しました; 再試行中...",
	"u_ehssrch": "サーバーは検索実行リクエストを拒否しました; 再試行中...",
	"u_ehsinit": "サーバーはアップロード開始リクエストを拒否しました; 再試行中...",
	"u_eneths": "アップロードハンドシェイク中にネットワークエラーが発生しました; 再試行中...",
	"u_enethd": "ターゲットの存在をテスト中にネットワークエラーが発生しました; 再試行中...",
	"u_cbusy": "ネットワークの不具合後サーバーが再び信頼するのを待っています...",
	"u_ehsdf": "サーバーのディスク容量が不足しました！\n\n誰かが十分な空き領域を確保して続行できるようになるまで\n再試行を続けます",
	"u_emtleak1": "お使いのウェブブラウザでメモリリークが発生している可能性があります;\nお願いします",
	"u_emtleak2": ' <a href="{0}">httpsに切り替える（推奨）</a>もしくは',
	"u_emtleak3": ' ',
	"u_emtleakc": '次を試してください:\n<ul><li><code>F5</code>を押してページを更新してください</li><li>次に&nbsp;<code>mt</code>を無効にします&nbsp; &nbsp;<code>⚙️ settings</code></li>ボタンをクリックし<li>もう一度アップロードしてみてください</li></ul>アップロードは少し遅くなりますが、仕方ないでしょう。\nご迷惑をおかけして申し訳ありません！\n\n追記: chrome v107ではこの問題が<a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">修正されました</a>',
	"u_emtleakf": '次を試してください:\n<ul><li><code>F5</code>を押してページを更新してください</li><li>アップロードUIで<code>🥔</code>（ポテト）を有効にして<li>もう一度アップロードを試してください</li></ul>\n追記: firefoxは<a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">バグ修正が行われることを期待しています</a>',
	"u_s404": "サーバー上にファイルが見つかりません",
	"u_expl": "説明",
	"u_maxconn": "ほとんどのブラウザではこの数が6に制限されていますが、Firefoxでは<code>about:config</code>の<code>connections-per-server</code>でこの数を増やすことができます",
	"u_tu": '<p class="warn">警告: ターボが有効になっている場合、<span>&nbsp;クライアントは不完全なアップロードを検出して再開できない可能性があります; ターボボタンのツールチップを見る</span></p>',
	"u_ts": '<p class="warn">警告: ターボが有効になっている場合、<span>&nbsp;検索結果が間違っている可能性があります; ターボボタンのツールチップを見る</span></p>',
	"u_turbo_c": "サーバー設定でターボが無効になっています",
	"u_turbo_g": "このボリューム内でディレクトリ一覧表示の権限がないため\nターボを無効化しています",
	"u_life_cfg": '<input id="lifem" p="60" />分後に自動削除（もしくは<input id="lifeh" p="3600" />時間）',
	"u_life_est": 'アップロードは削除されます <span id="lifew" tt="local time">---</span>',
	"u_life_max": 'このフォルダーの最大保存期間が\n{0}に設定されています。',
	"u_unp_ok": '{0}に対して未投稿が許可されています',
	"u_unp_ng": '未投稿は許可されません',
	"ue_ro": 'このフォルダのアクセス権限は読み取り専用です\n\n',
	"ue_nl": '現在ログインしていません',
	"ue_la": '現在"{0}"としてログインしています',
	"ue_sr": '現在ファイル検索モードです\n\n虫眼鏡 🔎（大きな検索ボタンの横）をクリックしてアップロードモードに切り替え、もう一度アップロードしてみてください。\n\n申し訳ありません',
	"ue_ta": 'もう一度アップロードしてみてください。今度は動作するはずです。',
	"ue_ab": "このファイルはすでに別のフォルダにアップロード中です。それが完了するまでこのファイルを他の場所にアップロードすることはできません。\n\n左上の🧯を使用して最初のアップロードを中止して忘れることができます。",
	"ur_1uo": "OK: ファイルのアップロードに成功しました",
	"ur_auo": "OK: {0}件すべてのファイルが正常にアップロードされました",
	"ur_1so": "OK: ファイルがサーバー上で見つかりました",
	"ur_aso": "OK: {0}件すべてのファイルがサーバー上で見つかりました",
	"ur_1un": "アップロードに失敗しました。申し訳ありません。",
	"ur_aun": "{0}件すべてのファイルのアップロードに失敗しました。申し訳ありません。",
	"ur_1sn": "サーバー上にファイルが見つかりません",
	"ur_asn": "サーバー上に {0}件のファイルが見つかりませんでした",
	"ur_um": "完了;\n{0}件のアップロードはOKです,\n{1}件のアップロードに失敗しました。申し訳ありません。",
	"ur_sm": "完了;\n{0}件のファイルがサーバー上に見つかりました,\n{1}件のファイルがサーバー上に見つかりませんでした",

	"rc_opn": "開く",
	"rc_ply": "再生",
	"rc_pla": "オーディオとして再生",
	"rc_txt": "ファイルビューアで開く",
	"rc_md": "markdownエディターで開く",
	"rc_dl": "ダウンロード",
	"rc_zip": "圧縮してダウンロード",
	"rc_cpl": "リンクをコピー",
	"rc_del": "削除",
	"rc_cut": "切り取り",
	"rc_cpy": "コピー",
	"rc_pst": "貼り付け",
	"rc_rnm": "名前を変更", //m
	"rc_nfo": "新しいフォルダ",
	"rc_nfi": "新しいファイル",
	"rc_sal": "すべて選択",
	"rc_sin": "選択を反転",
	"rc_shf": "このフォルダを共有", //m
	"rc_shs": "選択項目を共有", //m

	"lang_set": "変更を反映させるために更新しますか？",

	"splash": {
		"a1": "更新",
		"b1": "やあ、見知らぬ人 &nbsp; <small>（あなたはログインしていません）</small>",
		"c1": "ログアウト",
		"d1": "dump stack",  // トピックノート: "d2" はこのボタンのツールチップです
		"d2": "すべてのアクティブなスレッドの状態を表示します",
		"e1": "cfgの再読み込み",
		"e2": "設定ファイル（アカウント/ボリューム/ボリュームフラグ）を再読み込みして、$Nすべてのe2dsボリュームを再スキャンします$N$N注: グローバル設定の変更を$N有効にするには完全な再起動が必要です",
		"f1": "閲覧可能:",
		"g1": "アップロード加納:",
		"cc1": "その他:",
		"h1": "k304を無効化",  // トピックノート: "j1" はk304が何であるかを説明します
		"i1": "k304を有効化",
		"j1": "k304 を有効にすると、HTTP 304ごとにクライアントが切断されバグのあるプロキシがスタックするのを防ぐことができます（突然ページが読み込まれなくなるなど）<em>ただし</em>全体的に速度が低下します",
		"k1": "クライアント設定をリセット",
		"l1": "詳しくはログインしてください:",
		"ls3": "ログイン",
		"lu4": "ユーザー名",
		"lp4": "パスワード",
		"lo3": "「{0}」をどこからでもログアウトする",
		"lo2": "これによりすべてのブラウザでセッションが終了します",
		"m1": "おかえりなさい、",  // トピックノート: "おかえりなさい、ユーザー名"
		"n1": "404 not found &nbsp;┐( ´ -`)┌",
		"o1": 'あるいはアクセスできないかもしれません -- パスワードを試すか <a href="' + SR + '/?h">ホームに戻ってください</a>',
		"p1": "403 forbiddena &nbsp;~┻━┻",
		"q1": 'パスワードを使うか <a href="' + SR + '/?h">ホームに戻ってください</a>',
		"r1": "ホームに戻る",
		".s1": "再スキャン",
		"t1": "アクション",  // トピックノート: これは"再スキャン"ボタンの上のヘッダーです
		"u2": "最後のサーバー書き込みからの時間$N（アップロード / 名前変更 / ...）$N$N17d = 17日$N1h23 = 1時間23分$N4m56 = 4分56秒",
		"v1": "接続",
		"v2": "このサーバーをローカルHDDとして使用する",
		"w1": "httpsへ切り替え",
		"x1": "パスワードの変更",
		"y1": "共有の編集",  // トピックノート: ユーザーが共有することを決定したフォルダのリストを表示します
		"z1": "この共有のロックを解除する:",  // トピックノート: 隠し共有を表示するためのパスワードプロンプト
		"ta1": "最初に新しいパスワードを入力してください",
		"ta2": "確認のため新しいパスワードを再入力してください:",
		"ta3": "タイプミスを発見しました; もう一度試してください",
		"nop": "エラー: パスワードは空白にできません",
		"nou": "エラー: ユーザー名とパスワードは空白にできません",
		"aa1": "受信ファイル:",
		"ab1": "no304を無効化",
		"ac1": "no304を有効化",
		"ad1": "no304を有効にするとすべてのキャッシュが無効になります; k304 では不十分な場合はこちらをお試しください。これにより膨大な量のネットワークトラフィックが無駄になります！",
		"ae1": "アクティブなダウンロード:",
		"af1": "最近のアップロードを表示",
		"ag1": "idpキャッシュを表示",  // トピックノート: IdPユーザーを管理できるページへのリンクです
	}
};
